import { Body, Controller, Del, Get, Inject, Param, Post, Query } from '@midwayjs/decorator';
import { BaseController } from 'free-midway-component';
import { ChatService } from '../../service/platform/chat.service';
import { CDTO_chat, CVO_chat, FVO_chat, QVO_chat, UDTO_chat, UVAO_chat } from '../../interface/platform/chat.interface';
import { ApiResponse, ApiTags, ApiQuery } from '@midwayjs/swagger';
import { Validate } from '@midwayjs/validate';
@ApiTags(['聊天记录'])
@Controller('/chat')
export class ChatController extends BaseController {
  @Inject()
  service: ChatService;

  @Post('/')
  @Validate()
  @ApiResponse({ type: CVO_chat })
  async create(@Body() data: CDTO_chat) {
    const dbData = await this.service.create(data);
    const result = new CVO_chat(dbData);
    await this.service.createAfter(result);
    return result;
  }

  @Get('/')
  @ApiQuery({ name: 'query' })
  @ApiResponse({ type: QVO_chat })
  async query(@Query() filter) {
    const list = await this.service.query(filter);
    return list;
  }

  @Get('/read')
  @ApiQuery({ name: 'query' })
  async user(@Query() filter: any) {
    const result = await this.service.read(filter);
    return result;
  }

  @Get('/chat')
  @ApiQuery({ name: 'query' })
  async chat(@Query() filter) {
    const list = await this.service.chat(filter);
    return list;
  }

  @Get('/:id')
  @ApiResponse({ type: FVO_chat })
  async fetch(@Param('id') id: string) {
    const data = await this.service.fetch(id);
    const result = new FVO_chat(data);
    return result;
  }

  @Post('/:id')
  @Validate()
  @ApiResponse({ type: UVAO_chat })
  async update(@Param('id') id: string, @Body() body: UDTO_chat) {
    const result = await this.service.updateOne(id, body);
    return result;
  }

  @Del('/:id')
  @Validate()
  async delete(@Param('id') id: string) {
    await this.service.delete(id);
    return 'ok';
  }
  async createMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async updateMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async deleteMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }
}
