import { Body, Controller, Del, Get, Inject, Param, Post, Query } from '@midwayjs/decorator';
import { BaseController } from 'free-midway-component';
import { SignService } from '../../service/platform/sign.service';
import { CDTO_sign, CVO_sign, FVO_sign, QDTO_sign, QVO_sign, UDTO_sign, UVAO_sign } from '../../interface/platform/sign.interface';
import { ApiResponse, ApiTags, ApiQuery } from '@midwayjs/swagger';
import { Validate } from '@midwayjs/validate';
@ApiTags(['赛事报名表'])
@Controller('/sign')
export class SignController extends BaseController {
  @Inject()
  service: SignService;

  @Post('/')
  @Validate()
  @ApiResponse({ type: CVO_sign })
  async create(@Body() data: CDTO_sign) {
    await this.service.createExamine(data);
    const dbData = await this.service.create(data);
    const result = new CVO_sign(dbData);
    return result;
  }
  @Get('/')
  @ApiQuery({ name: 'query' })
  @ApiResponse({ type: QVO_sign })
  async query(@Query() filter: QDTO_sign, @Query('skip') skip: number, @Query('limit') limit: number) {
    const list = await this.service.query(filter, { skip, limit });
    const data = [];
    for (const i of list) {
      const newData = new QVO_sign(i);
      data.push(newData);
    }
    const total = await this.service.count(filter);
    return { data, total };
  }

  @Get('/sign')
  async sign(@Query() filter) {
    const list = await this.service.sign(filter);
    return list;
  }

  @Get('/:id')
  @ApiResponse({ type: FVO_sign })
  async fetch(@Param('id') id: string) {
    const data = await this.service.fetch(id);
    const result = new FVO_sign(data);
    return result;
  }

  @Post('/:id')
  @Validate()
  @ApiResponse({ type: UVAO_sign })
  async update(@Param('id') id: string, @Body() body: UDTO_sign) {
    const result = await this.service.updateOne(id, body);
    return result;
  }

  @Del('/:id')
  @Validate()
  async delete(@Param('id') id: string) {
    await this.service.delete(id);
    return 'ok';
  }
  async createMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async updateMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async deleteMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }
}
