import { Body, Controller, Del, Get, Inject, Param, Post, Query } from '@midwayjs/decorator';
import { BaseController } from 'free-midway-component';
import { SupplyService } from '../../service/platform/supply.service';
import { CDTO_supply, CVO_supply, FVO_supply, QDTO_supply, QVO_supply, UDTO_supply, UVAO_supply } from '../../interface/platform/supply.interface';
import { ApiResponse, ApiTags, ApiQuery } from '@midwayjs/swagger';
import { Validate } from '@midwayjs/validate';
@ApiTags(['供给'])
@Controller('/supply')
export class SupplyController extends BaseController {
  @Inject()
  service: SupplyService;

  @Post('/')
  @Validate()
  @ApiResponse({ type: CVO_supply })
  async create(@Body() data: CDTO_supply) {
    const dbData = await this.service.create(data);
    const result = new CVO_supply(dbData);
    return result;
  }
  @Get('/')
  @ApiQuery({ name: 'query' })
  @ApiResponse({ type: QVO_supply })
  async query(@Query() filter: QDTO_supply, @Query('skip') skip: number, @Query('limit') limit: number) {
    const list = await this.service.query(filter, { skip, limit });
    const data = [];
    for (const i of list) {
      const newData = new QVO_supply(i);
      data.push(newData);
    }
    const total = await this.service.count(filter);
    return { data, total };
  }

  @Get('/list')
  async list() {
    const list = await this.service.list(this.ctx.filter);
    const data = list.data;
    const total = list.total;
    return { data, total };
  }


  @Get('/detail/:id')
  @ApiResponse({ type: FVO_supply })
  async detail(@Param('id') id: string) {
    const data = await this.service.detail(id);
    return data;
  }

  @Get('/:id')
  @ApiResponse({ type: FVO_supply })
  async fetch(@Param('id') id: string) {
    const data = await this.service.fetch(id);
    const result = new FVO_supply(data);
    return result;
  }

  @Post('/:id')
  @Validate()
  @ApiResponse({ type: UVAO_supply })
  async update(@Param('id') id: string, @Body() body: UDTO_supply) {
    const result = await this.service.updateOne(id, body);
    return result;
  }

  @Del('/:id')
  @Validate()
  async delete(@Param('id') id: string) {
    await this.service.delete(id);
    return 'ok';
  }
  async createMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async updateMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async deleteMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }
}
