import { Body, Controller, Del, Get, Inject, Param, Post, Query } from '@midwayjs/decorator';
import { BaseController } from 'free-midway-component';
import { CompanyService } from '../../service/users/company.service';
import { CDTO_company, CVO_company, FVO_company, QDTO_company, QVO_company, UDTO_company, UVAO_company } from '../../interface/users/company.interface';
import { ApiResponse, ApiTags, ApiQuery } from '@midwayjs/swagger';
import { Validate } from '@midwayjs/validate';
import { UtilService } from '../../service/util.service';
@ApiTags(['企业'])
@Controller('/company')
export class CompanyController extends BaseController {
  @Inject()
  service: CompanyService;

  @Inject()
  utilService: UtilService;

  @Post('/')
  @Validate()
  @ApiResponse({ type: CVO_company })
  async create(@Body() data: CDTO_company) {
    const dbData = await this.service.create(data);
    const result = new CVO_company(dbData);
    return result;
  }
  @Get('/')
  @ApiQuery({ name: 'query' })
  @ApiResponse({ type: QVO_company })
  async query(@Query() filter: QDTO_company, @Query('skip') skip: number, @Query('limit') limit: number) {
    const list = await this.service.query(filter, { skip, limit });
    const data = [];
    for (const i of list) {
      const newData = new QVO_company(i);
      data.push(newData);
    }
    const total = await this.service.count(filter);
    return { data, total };
  }

  @Get('/list')
  async list() {
    const list = await this.service.list(this.ctx.filter);
    const data = list.data;
    const total = list.total;
    return { data, total };
  }

  @Get('/:id')
  @ApiResponse({ type: FVO_company })
  async fetch(@Param('id') id: string) {
    const data = await this.service.fetch(id);
    const result = new FVO_company(data);
    return result;
  }

  @Get('/detail/:id')
  @ApiResponse({ type: FVO_company })
  async detail(@Param('id') id: string) {
    const data = await this.service.detail(id);
    return data;
  }

  @Post('/:id')
  @Validate()
  @ApiResponse({ type: UVAO_company })
  async update(@Param('id') id: string, @Body() body: UDTO_company) {
    const result = await this.service.updateOne(id, body);
    await this.utilService.updateUserAfter(id, body, 'Company');
    return result;
  }

  @Del('/:id')
  @Validate()
  async delete(@Param('id') id: string) {
    await this.service.delete(id);
    return 'ok';
  }
  async createMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async updateMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async deleteMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }
}
