import { Body, Controller, Del, Get, Inject, Param, Post, Query } from '@midwayjs/decorator';
import { BaseController } from 'free-midway-component';
import { InvestmentService } from '../../service/users/investment.service';
import { CDTO_investment, CVO_investment, FVO_investment, QDTO_investment, QVO_investment, UDTO_investment, UVAO_investment } from '../../interface/users/investment.interface';
import { ApiResponse, ApiTags, ApiQuery } from '@midwayjs/swagger';
import { Validate } from '@midwayjs/validate';
import { UtilService } from '../../service/util.service';
@ApiTags(['投资人'])
@Controller('/investment')
export class InvestmentController extends BaseController {
  @Inject()
  service: InvestmentService;

  @Inject()
  utilService: UtilService;

  @Post('/')
  @Validate()
  @ApiResponse({ type: CVO_investment })
  async create(@Body() data: CDTO_investment) {
    const dbData = await this.service.create(data);
    const result = new CVO_investment(dbData);
    return result;
  }
  @Get('/')
  @ApiQuery({ name: 'query' })
  @ApiResponse({ type: QVO_investment })
  async query(@Query() filter: QDTO_investment, @Query('skip') skip: number, @Query('limit') limit: number) {
    const list = await this.service.query(filter, { skip, limit });
    const data = [];
    for (const i of list) {
      const newData = new QVO_investment(i);
      data.push(newData);
    }
    const total = await this.service.count(filter);
    return { data, total };
  }

  @Get('/:id')
  @ApiResponse({ type: FVO_investment })
  async fetch(@Param('id') id: string) {
    const data = await this.service.fetch(id);
    const result = new FVO_investment(data);
    return result;
  }

  @Post('/:id')
  @Validate()
  @ApiResponse({ type: UVAO_investment })
  async update(@Param('id') id: string, @Body() body: UDTO_investment) {
    const result = await this.service.updateOne(id, body);
    await this.utilService.updateUserAfter(id, body, 'Investment');
    return result;
  }

  @Del('/:id')
  @Validate()
  async delete(@Param('id') id: string) {
    await this.service.delete(id);
    return 'ok';
  }
  async createMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async updateMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async deleteMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }
}
