import { Provide } from '@midwayjs/decorator';
import { InjectEntityModel } from '@midwayjs/typegoose';
import { ReturnModelType } from '@typegoose/typegoose';
import { BaseService } from 'free-midway-component';
import { Dept } from '../../entity/system/dept.entity';
type modelType = ReturnModelType<typeof Dept>;
import { Types } from 'mongoose';
import { get, isObject, orderBy } from 'lodash';
const ObjectId = Types.ObjectId;
@Provide()
export class DeptService extends BaseService<modelType> {
  @InjectEntityModel(Dept)
  model: modelType;

  async queryAll() {
    const data = await this.model.find({}, { meta: 0, __v: 0 }).sort({ order_num: 1 }).lean();
    let treeData = data.filter(f => !f.parent_id);
    treeData = this.treeData(data, treeData);
    return treeData;
  }

  async getNextLevel(id: string, query = { skip: 0, limit: 10 }) {
    const data: any = await this.model
      .find({ parent_id: id })
      .skip(query.skip)
      .limit(query.limit)
      .populate({
        path: 'parent_id',
        select: 'name',
        model: 'Dept',
      })
      .sort({ order_num: 1 })
      .lean();
    data.map(i => {
      if (isObject(get(i, 'parent_id'))) {
        i.parent_id_name = get(i, 'parent_id.name');
        i.parent_id = get(i, 'parent_id._id');
      }
      return i;
    });
    const total = await this.model.count({ parent_id: id });
    return { data, total };
  }

  treeData(allList, nowList) {
    for (const nm of nowList) {
      const { _id, parent_id } = nm;
      // 查下下级其是否有目录
      let children = allList.filter(f => new ObjectId(f.parent_id).equals(_id));
      children = this.treeData(allList, children);
      if (children.length > 0) nm.children = children;
      // 换父级组件的名称
      if (parent_id) {
        const r = allList.find(f => new ObjectId(f._id).equals(parent_id));
        if (r) nm.parent_name = r.name;
      }
    }
    nowList = orderBy(nowList, ['order_num'], ['asc']);
    return nowList;
  }
}
